
import 'package:attestr_flowx_plugin/attestr_flowx_plugin_platform_interface.dart';
import 'package:eventify/eventify.dart';
import 'package:flutter/services.dart';

class AttestrFlowxPlugin {

  static const MethodChannel platform = MethodChannel('attestr_flowx_plugin');
  late Map<String, Object> result;
  late EventEmitter _eventEmitter;
  // Response codes from platform
  static const FLOW_COMPLETE = 0;
  static const FLOW_SKIP = 1;
  static const FLOW_ERROR = 2;

  // Event names
  static const EVENT_FLOW_COMPLETE = 'flow.success';
  static const EVENT_FLOW_SKIP = 'flow.skip';
  static const EVENT_FLOW_ERROR = 'flow.error';

  AttestrFlowxPlugin() {
    _eventEmitter = EventEmitter();
  }

  void initiateSession(
      String handshakeID,
      String clientKey,
      String locale
      ) async {
    try {
      result = await platform.invokeMethod(
          'initiateSession',
          {
            "hs": handshakeID,
            "cl": clientKey,
            "lc": locale
          }
      );
      _handleResult(result);
    } on PlatformException catch (e) {
      print(e.toString());
    }
  }

  void _handleResult(Map<dynamic, dynamic> response) {
    switch (response['type']) {
      case FLOW_COMPLETE:
        _eventEmitter.emit(EVENT_FLOW_COMPLETE, null, response['message']);
        break;
      case FLOW_SKIP:
        _eventEmitter.emit(EVENT_FLOW_SKIP , null, response['message']);
        break;
      case FLOW_ERROR:
        _eventEmitter.emit(EVENT_FLOW_ERROR, null, response['message']);
        break;
    }
  }

  // Registers event listeners
  void on(String event, Function handler) {
    EventCallback cb = (event, cont) {
      handler(event.eventData);
    };
    _eventEmitter.on(event, null, cb);
  }

  // Clears all event listeners
  void clear() {
    _eventEmitter.clear();
  }

  Future<String?> getPlatformVersion() {
    return AttestrFlowxPluginPlatform.instance.getPlatformVersion();
  }

}
